@@ -7,6 +7,7 @@ from pydantic import BaseModel
 from copy import deepcopy
 
 import requests
+import mimetypes
 
 from ..models.assistant import (
     Assistant,
@@ -205,7 +206,15 @@ class AssistantService:
 
         with open(file_path, "rb") as file:
             files = [
-                ("file", (file_path.name, file, self._api.detect_mime_type(file_path)))
+                (
+                    "file",
+                    (
+                        file_path.name,
+                        file,
+                        mimetypes.guess_type(file_path.name)
+                        or "application/octet-stream",
+                    ),
+                ),
             ]
             response = self._api.post_multipart("/v1/files/", dict, files=files)
 
